/*
 * Each Counter object has its own/separate copy of the integer counter "l" (local). 
 * All objects instantiated from the Counter class share a single copy of the integer counter "g" (global).
 */
public class Counter {
	private int l; /* this is a non-static (instance-specific) variable */
	static int g = 0; /* this is a static (global) variable */
	
	public Counter() {
		this.l = 0;
	}
	
	public int getLocal() {
		return this.l;
	} 
	
	/* A mutator method that changes the local
	 * value of the context object. */
	public void incrementLocal() {
		this.l ++;
	}
	
	/* A mutator method that changes the global
	 * value, which is shared by all objects. */
	public void incrementGlobal() {
		/*
		 * A static variable should be accessed through its declaring class (e.g., Counter.g).
		 */
		this.g ++; // warning: static g is not accessed in a static way 
	}
}